==> sciqlopplots-0.11.0.tar.gz: sciqlopplots-0.11.0/src/SciQLopPixmapItem.cpp <==
/*------------------------------------------------------------------------------
-- This file is a part of the SciQLop Software
-- Copyright (C) 2025, Plasma Physics Laboratory - CNRS
--
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-------------------------------------------------------------------------------*/
/*-- Author : Alexis Jeandet
-- Mail : alexis.jeandet@member.fsf.org
----------------------------------------------------------------------------*/
#include "SciQLopPlots/Items/SciQLopPixmapItem.hpp"

void PixmapItem::move(double dx, double dy)
{
    this->topLeft->setPixelPosition({ this->topLeft->pixelPosition().x() + dx, this->topLeft->pixelPosition().y() + dy });
    this->bottomRight->setPixelPosition({ this->bottomRight->pixelPosition().x() + dx, this->bottomRight->pixelPosition().y() + dy });
    this->replot();
    emit moved(this->topLeft->coords().x(), this->topLeft->coords().y());
}

==> sciqlopplots-0.15.0.tar.gz: sciqlopplots-0.15.0/src/SciQLopPixmapItem.cpp <==
/*------------------------------------------------------------------------------
-- This file is a part of the SciQLop Software
-- Copyright (C) 2025, Plasma Physics Laboratory - CNRS
--
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-------------------------------------------------------------------------------*/
/*-- Author : Alexis Jeandet
-- Mail : alexis.jeandet@member.fsf.org
----------------------------------------------------------------------------*/
#include "SciQLopPlots/Items/SciQLopPixmapItem.hpp"

void impl::PixmapItem::move(double dx, double dy)
{
    this->topLeft->setPixelPosition({ this->topLeft->pixelPosition().x() + dx, this->topLeft->pixelPosition().y() + dy });
    this->bottomRight->setPixelPosition({ this->bottomRight->pixelPosition().x() + dx, this->bottomRight->pixelPosition().y() + dy });
    this->replot();
    emit moved(this->topLeft->coords().x(), this->topLeft->coords().y());
}
